==> kvirc-3.0.1.tar.bz2: kvirc-3.0.1/src/modules/dcc/canvas.h <==
#ifndef _CANVAS_H_
#define _CANVAS_H_
//
//   File : canvas.h
//   Creation date : Sun Jul 29 07 2001 20:17:12 by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 2001 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#include "kvi_window.h"
#include "kvi_string.h"

#include "descriptor.h"
#include "window.h"
#include "thread.h"

#include "kvi_list.h"



class KviDccMarshal;
class KviCanvasWidget;

class QSplitter;


class KviDccCanvas : public KviDccWindow
{
	Q_OBJECT
public:
	KviDccCanvas(KviFrame *pFrm,KviDccDescriptor * dcc,const char * name);
	~KviDccCanvas();
protected:
//	KviDccCanvasThread     * m_pSlaveThread;
	KviCanvasWidget        * m_pCanvas;
//	QSplitter              * m_pTopSplitter;
	KviStr                   m_szTarget;
protected:
	virtual const char * target();
	virtual void fillCaptionBuffers();
	virtual void getBaseLogFileName(KviStr &buffer);
	virtual QPixmap * myIconPtr();
	virtual void resizeEvent(QResizeEvent *e);
	virtual QSize sizeHint() const;
	virtual bool event(QEvent *e);
	virtual void ownMessage(const char *text);
	virtual void ownAction(const char *text);
protected slots:
	void handleMarshalError(int err);
	void connected();
};



#endif // _CANVAS_H_

==> kvirc-3.2.6.tar.bz2: kvirc-3.2.6/src/modules/dcc/canvas.h <==
#ifndef _CANVAS_H_
#define _CANVAS_H_
//
//   File : canvas.h
//   Creation date : Sun Jul 29 07 2001 20:17:12 by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 2001 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#include "kvi_window.h"
#include "kvi_string.h"

#include "descriptor.h"
#include "window.h"
#include "thread.h"

#include "kvi_list.h"



class KviDccMarshal;
class KviCanvasWidget;

class QSplitter;


class KviDccCanvas : public KviDccWindow
{
	Q_OBJECT
public:
	KviDccCanvas(KviFrame *pFrm,KviDccDescriptor * dcc,const char * name);
	~KviDccCanvas();
protected:
//	KviDccCanvasThread     * m_pSlaveThread;
	KviCanvasWidget        * m_pCanvas;
//	QSplitter              * m_pTopSplitter;
	QString                  m_szTarget;
protected:
	virtual const QString &target();
	virtual void fillCaptionBuffers();
	virtual void getBaseLogFileName(KviStr &buffer);
	virtual QPixmap * myIconPtr();
	virtual void resizeEvent(QResizeEvent *e);
	virtual QSize sizeHint() const;
	virtual bool event(QEvent *e);
	virtual void ownMessage(const char *text);
	virtual void ownAction(const char *text);
protected slots:
	void handleMarshalError(int err);
	void connected();
};



#endif // _CANVAS_H_
